from ..mata_uang import asia, eropa, australia, afrika, amerika

class ISO:
    def __init__(self):
        self.iso_benua_asia = asia.Asia().iso4217
        self.iso_benua_eropa = eropa.Eropa().iso4217
        self.iso_benua_australia = australia.Australia().iso4217
        self.iso_benua_afrika = afrika.Afrika().iso4217
        self.iso_benua_amerika_utara = amerika.amerika_utara.AmerikaUtara().iso4217
        self.iso_benua_amerika_selatan = amerika.amerika_selatan.AmerikaSelatan().iso4217 

class Negara:
    def __init__(self):
        self.negara_benua_asia = asia.Asia().negara
        self.negara_benua_eropa = eropa.Eropa().negara
        self.negara_benua_australia = australia.Australia().negara
        self.negara_benua_afrika = afrika.Afrika().negara
        self.negara_benua_amerika_utara = amerika.amerika_utara.AmerikaUtara().negara
        self.negara_benua_amerika_selatan = amerika.amerika_selatan.AmerikaSelatan().negara

class IsoNegara:
    def __init__(self):
        iso = ISO()
        negara = Negara()
        self.data_asia = dict(zip(negara.negara_benua_asia, iso.iso_benua_asia))
        self.data_eropa = dict(zip(negara.negara_benua_eropa, iso.iso_benua_eropa))
        self.data_afrika = dict(zip(negara.negara_benua_afrika, iso.iso_benua_afrika))
        self.data_australia = dict(zip(negara.negara_benua_australia, iso.iso_benua_australia))
        self.data_amerika_utara = dict(zip(negara.negara_benua_amerika_utara, iso.iso_benua_amerika_utara))
        self.data_amerika_selatan = dict(zip(negara.negara_benua_amerika_selatan, iso.iso_benua_amerika_selatan))



from typing import Dict, List
import os.path as jalur
import json


# buat jalur baru berdasarkan berkas saat ini 
def jalur_berkas(nama: str) -> str:
    objek = jalur.abspath(__file__)
    utama = jalur.dirname(objek)
    return jalur.join(utama, "{}.json".format(nama))

class DataSelatan:
    def __init__(self):
        with open(jalur_berkas('amerika_selatan')) as data:
            self.data_json: Dict[str, str] = json.load(data)
        self.data_indeks: List[str] = [k for data in range(len(self.data_json)) for k in self.data_json[data].keys()]

    def huruf(self, abjat: str) -> List[Dict[str, str]]:
        besar = abjat.upper()
        indeks = self.data_indeks.index(besar)
        return self.data_json[indeks][besar]

class BidangSelatan:
    def __init__(self, huruf: str):
        data = DataSelatan().huruf(huruf)
        self.negara: List[str] = [data[i]["Negara"] for i in range(len(data))]
        self.iso4217: List[str] = [data[i]["ISO"] for i in range(len(data))]

class AmerikaSelatan:
    def __init__(self):
        indeks = DataSelatan().data_indeks
        self.negara : List[str]= tuple([negara for j in indeks for negara in BidangSelatan(j).negara])
        self.iso4217: List[str] = tuple([iso for j in indeks for iso in BidangSelatan(j).iso4217])

    def huruf(self, abjat: str) -> List[Dict[str, str]]:
        return DataSelatan().huruf(abjat)


